<?php
namespace Ep\Wp\View;

use Ep\View\Renderer\RendererAwareInterface;
use Zend\View\HelperPluginManager;
use Zend\View\Renderer\RendererInterface;

/**
 * Osnovna klasa za WordPress viewove.
 *
 * @package Ep\Wp\View
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
abstract class AbstractView implements
    RendererAwareInterface,
    ViewInterface
{
    /** @var RendererInterface */
    protected $renderer;
    /** @var HelperPluginManager */
    protected $helpers;

    /**
     * View možda nema što za nakačiti.
     */
    public function init(): void
    { }

    /**
     * @return RendererInterface
     */
    public function getRenderer(): RendererInterface
    {
        return $this->renderer;
    }

    /**
     * @param RendererInterface $renderer
     */
    public function setRenderer(RendererInterface $renderer): void
    {
        $this->renderer = $renderer;

        if (method_exists($renderer, 'getHelperPluginManager')) {
            $this->helpers = $renderer->getHelperPluginManager();
        }
    }

    /**
     * Osnovno implementacija ispisuje render().
     */
    public function output(): void
    {
        echo call_user_func_array([$this, 'render'], func_get_args());
    }
}